package com.amqp.shanxi.service;

import cn.hutool.json.JSONUtil;
import com.amqp.shanxi.ShanxiApplication;
import com.amqp.shanxi.model.StaticDataInfoModel;
import com.amqp.shanxi.service.impl.DeviceStaticDataInfoServiceImpl;
import com.amqp.shanxi.util.AMQPTopicStaticDataConfig;
import com.rabbitmq.client.Channel;
import com.rabbitmq.client.Connection;
import org.springframework.amqp.rabbit.core.RabbitTemplate;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;


@Service
public class DeviceStaticDataAMQPService {

    @Autowired
    private DeviceStaticDataInfoService deviceStaticDataInfoService;

    @Autowired
    private SensorDataService sensorDataService;

    public void run(Connection connection) {
        try{
            List<String> sensorKind = sensorDataService.findSensorKind();
            // 设备信息
            this.publish("basic", connection);
            for (String kind: sensorKind) {
                if ("干滩".equals(kind)) {
                    this.publish("gt", connection);
                } else if("库水位".equals(kind)) {
                    this.publish("ksw",connection);
                }else if("坝体表面位移".equals(kind)) {
                    this.publish("bmwy", connection);
                }else if("浸润线".equals(kind)) {
                    this.publish("jrx", connection);
                }else if("雨量计".equals(kind)) {
                    this.publish("jyl", connection);
                }else if("内部位移".equals(kind)) {
                    this.publish("nbwy", connection);
                }
            }


        }catch(Exception e) {
            e.printStackTrace();
        }
    }


    public void publish(String type, Connection connection) {
        try {
            if ("basic".equals(type)) {
                Channel channel = connection.createChannel();
                // channel.exchangeDeclare(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE, "topic", false, true, null);
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_BAISC
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.wkkBasicDataInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("尾矿库基础信息发送成功！");
                } else {
                    System.out.println("尾矿库基础信息发送失败！");
                }
                channel.close();
            } else if ("gt".equals(type)) {
                Channel channel = connection.createChannel();
                // channel.exchangeDeclare(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE, "topic", false, true, null);
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_GANTAN
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.gantanDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("干滩设备信息发送成功！");
                } else {
                    System.out.println("干滩设备信息发送失败！");
                }
                channel.close();
            } else if ("ksw".equals(type)) {
                Channel channel = connection.createChannel();
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_KUSHUIWEI
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.kushuiweiDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("库水位设备信息发送成功！");
                } else {
                    System.out.println("库水位设备信息发送失败！");
                }
                channel.close();
                
            } else if ("bmwy".equals(type)) {
                Channel channel = connection.createChannel();
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_BIAOMIANWEIYI
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.biaomianweiyiDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("表面位移设备信息发送成功！");
                } else {
                    System.out.println("表面位移设备信息发送失败！");
                }
                channel.close();
                
            } else if ("nbwy".equals(type)) {
                Channel channel = connection.createChannel();
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_NEIBUWEIYI
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.neibuweiyiDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("内部位移设备信息发送成功！");
                } else {
                    System.out.println("内部位移设备信息发送失败！");
                }
                channel.close();
            } else if ("jrx".equals(type)) {
                Channel channel = connection.createChannel();
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_JINRUNXIAN
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.jinrunxianDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("浸润线设备信息发送成功！");
                } else {
                    System.out.println("浸润线设备信息发送失败！");
                }
                channel.close();
                
            } else if ("jyl".equals(type)) {
                Channel channel = connection.createChannel();
                channel.basicPublish(AMQPTopicStaticDataConfig.TOPIC_EXCHANGE
                        , AMQPTopicStaticDataConfig.TOPIC_ROUTINGKEY_JIANGYULIANG
                        , null
                        , JSONUtil.toJsonStr(deviceStaticDataInfoService.jiangyuliangDeviceInfo()).getBytes());
                //消息确认
                channel.confirmSelect();
                if (channel.waitForConfirms()) {
                    System.out.println("降雨量设备信息发送成功！");
                } else {
                    System.out.println("降雨量设备信息发送失败！");
                }
                channel.close();
                
            } else if ("sll".equals(type)) {

            }
        }catch(Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 以下是监听，接收队列中消息
     *
     */
   /* @RabbitListener(queues ="equipInfo.01" )
    public void receiveMessage1(String str){
        System.out.println("我是监听干滩topic.message的, 消息队列equipInfo.01:    " + str);
    }

    @RabbitListener(queues ="equipInfo.02" )
    public void receiveMessage2(String str){
        System.out.println("我是监听库水位topic.message的, 消息队列equipInfo.02:   " + str);
    }

    @RabbitListener(queues ="equipInfo.03" )
    public void receiveMessage3(String str){
        System.out.println("我是监听表面位移topic.message的, 消息队列equipInfo.03:  " + str);
    }

    @RabbitListener(queues ="equipInfo.05" )
    public void receiveMessage5(String str){
        System.out.println("我是监听浸润线topic.message的, 消息队列equipInfo.05:  " + str);
    }

    @RabbitListener(queues ="equipInfo.06" )
    public void receiveMessage6(String str){
        System.out.println("我是监听降雨量topic.message的, 消息队列equipInfo.06:  " + str);
    }*/
}
